@@ -1,6 +1,6 @@
 package Tapper::MCP::Net;
 our $AUTHORITY = 'cpan:TAPPER';
-$Tapper::MCP::Net::VERSION = '5.0.4';
+$Tapper::MCP::Net::VERSION = '5.0.5';
 use strict;
 use warnings;
 use English '-no_match_vars';
@@ -55,7 +55,8 @@ sub start_local
 {
         my ($self, $path_to_config) = @_;
 
-        my $error = qx(tapper-client --config $path_to_config);
+        my $tapper_script = $self->cfg->{files}{tapper_prc};
+        my $error = qx($tapper_script --config $path_to_config);
         return "Can not start PRC locally: $error" if $error;
         return 0;
 }
